@@ -18,10 +18,10 @@ void	call_pcg_dun_reset( void );
 void	call_pcg_dun_reset_update_flg( void );
 void	call_pcg_dun_draw( long map_x, long map_y, long map_w, long map_h );
 void	call_pcg_dun_scroll( long map_x, long map_y );
-long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool flag_one_draw );
-long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool flag_one_draw );
-long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool flag_one_draw );
-long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool flag_one_draw );
+long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flag_one_draw );
+long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flag_one_draw );
+long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flag_one_draw );
+long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flag_one_draw );
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY );
 void	call_stat_win_redraw( void );
 long	call_key_get_char( void );
