@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.34 2007/02/06 10:53:52 bowkenken Exp $
+* $Id: call.cpp,v 1.35 2007/02/06 20:11:12 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -480,15 +480,15 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 /***************************************************************
 * 饯κüκɸ֤
 * chr_t *chr : 饯
-* bool flagPre : 1 κɸ
+* bool_t flagPre : 1 κɸ
 ***************************************************************/
 
-long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool flag_one_draw )
+long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 {
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flagPre );
 	n = n / gPcgDun.getTileSizeX();
 
 	return n;
@@ -497,25 +497,30 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool flag_one_draw )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawLeft( chr, pPcg, flagPre );
 	n = n / gPcgDun.getTileSizeX();
 
 	return n;
 #endif // D_GTK
+
+	if( flagPre )
+		return get_chr_left( chr->pre_draw_x, chr->dx );
+	else
+		return get_chr_left( chr->x, chr->dx );
 }
 
 /***************************************************************
 * 饯αüκɸ֤
 * chr_t *chr : 饯
-* bool flagPre : 1 κɸ
+* bool_t flagPre : 1 κɸ
 ***************************************************************/
 
-long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool flag_one_draw )
+long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 {
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, flagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
 	return n;
@@ -524,25 +529,30 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool flag_one_draw )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawRight( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawRight( chr, pPcg, flagPre );
 	n = (n + gPcgDun.getTileSizeX() - 1) / gPcgDun.getTileSizeX();
 
 	return n;
 #endif // D_GTK
+
+	if( flagPre )
+		return get_chr_right( chr->pre_draw_x, chr->dx );
+	else
+		return get_chr_right( chr->x, chr->dx );
 }
 
 /***************************************************************
 * 饯ξüκɸ֤
 * chr_t *chr : 饯
-* bool flagPre : 1 κɸ
+* bool_t flagPre : 1 κɸ
 ***************************************************************/
 
-long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool flag_one_draw )
+long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 {
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, flagPre );
 	n = n / gPcgDun.getTileSizeY();
 
 	return n;
@@ -551,25 +561,30 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool flag_one_draw )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawTop( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawTop( chr, pPcg, flagPre );
 	n = n / gPcgDun.getTileSizeY();
 
 	return n;
 #endif // D_GTK
+
+	if( flagPre )
+		return get_chr_top( chr->pre_draw_y, chr->dy );
+	else
+		return get_chr_top( chr->y, chr->dy );
 }
 
 /***************************************************************
 * 饯βüκɸ֤
 * chr_t *chr : 饯
-* bool flagPre : 1 κɸ
+* bool_t flagPre : 1 κɸ
 ***************************************************************/
 
-long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool flag_one_draw )
+long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 {
 #ifdef D_WS
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
 	return n;
@@ -578,11 +593,16 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool flag_one_draw )
 #ifdef D_GTK
 	Pcg *pPcg = gPcgDun.getChrPcg( chr );
 
-	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flag_one_draw );
+	long n = gPcgDun.getChrDrawBottom( chr, pPcg, flagPre );
 	n = (n + gPcgDun.getTileSizeY() - 1) / gPcgDun.getTileSizeY();
 
 	return n;
 #endif // D_GTK
+
+	if( flagPre )
+		return get_chr_bottom( chr->pre_draw_y, chr->dy );
+	else
+		return get_chr_bottom( chr->y, chr->dy );
 }
 
 /***************************************************************
