@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw-tab.h,v 1.13 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: draw-tab.h,v 1.14 2007/02/02 19:45:13 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_TAB_H
@@ -272,6 +272,8 @@
 
 /* page 2/2 */
 
+/* lev left */
+
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_X	(0 + 4)
 #define	WIN_MBR_DATA_LEV_TTL_LEFT_DRAW_MIN_Y	2
 
@@ -283,17 +285,21 @@
 #define	WIN_MBR_DATA_NEED_EXP_TTL_LEFT_DRAW_MIN_Y	\
 		WIN_MBR_DATA_EXP_TTL_LEFT_DRAW_MIN_Y
 
+/* lev right */
+
 #define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_X	\
 		(WIN_MBR_DATA_DRAW_MID_X + 4)
-#define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y	0
+#define	WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y	2
 
 #define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_X	\
 		(WIN_MBR_DATA_DRAW_MID_X + 20)
-#define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y	0
+#define	WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y	\
+		WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y
 
 #define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_X	\
 		(WIN_MBR_DATA_DRAW_MID_X + 27)
-#define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_Y	0
+#define	WIN_MBR_DATA_NEED_EXP_TTL_RIGHT_DRAW_MIN_Y	\
+		WIN_MBR_DATA_EXP_TTL_RIGHT_DRAW_MIN_Y
 
 /* abl 1/2 */
 
@@ -413,6 +419,11 @@
 #define	WIN_MBR_DATA_RESI_POIS_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_RESI_DRAW_MIN_Y + 2)
 
+/* Class */
+
+#define	WIN_MBR_DATA_CLASS_TTL_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
+#define	WIN_MBR_DATA_CLASS_TTL_DRAW_MIN_Y	0
+
 /* abl 2/2 */
 
 #define	WIN_MBR_DATA_FIG_TTL_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
@@ -463,11 +474,7 @@
 #define	WIN_MBR_DATA_NIN_TTL_DRAW_MIN_Y	\
 		(WIN_MBR_DATA_LEV_TTL_RIGHT_DRAW_MIN_Y + 12)
 
-/* Class */
-
-#define	WIN_MBR_DATA_CLASS_TTL_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
-#define	WIN_MBR_DATA_CLASS_TTL_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_NIN_TTL_DRAW_MIN_Y + 2)
+/* Page */
 
 #define	WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
 #define	WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_Y	19
@@ -478,7 +485,7 @@
 
 #define	WIN_EDIT_CLASS_PREV_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
 #define	WIN_EDIT_CLASS_PREV_DRAW_MIN_Y	\
-		(WIN_MBR_DATA_CLASS_TTL_DRAW_MIN_Y + 2)
+		(WIN_MBR_DATA_NEXT_PAGE_DRAW_MIN_Y - 1)
 
 #define	WIN_EDIT_CLASS_NEXT_DRAW_MIN_X	WIN_MBR_DATA_DRAW_MID_X
 #define	WIN_EDIT_CLASS_NEXT_DRAW_MIN_Y	\
@@ -592,6 +599,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
+		FALSE,	/* DATA_N_CLASS, */
+
 		FALSE,	/* DATA_N_FIG, */
 		FALSE,	/* DATA_N_MON, */
 		FALSE,	/* DATA_N_HUN, */
@@ -605,8 +614,6 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
-		FALSE,	/* DATA_N_CLASS, */
-
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 	{
@@ -692,6 +699,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
+		TRUE,	/* DATA_N_CLASS, */
+
 		FALSE,	/* DATA_N_FIG, */
 		FALSE,	/* DATA_N_MON, */
 		FALSE,	/* DATA_N_HUN, */
@@ -705,8 +714,6 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
-		TRUE,	/* DATA_N_CLASS, */
-
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 	{
@@ -792,6 +799,8 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_RESI_ELEC, */
 		FALSE,	/* DATA_N_RESI_POIS, */
 
+		TRUE,	/* DATA_N_CLASS, */
+
 		FALSE,	/* DATA_N_FIG, */
 		FALSE,	/* DATA_N_MON, */
 		FALSE,	/* DATA_N_HUN, */
@@ -805,8 +814,6 @@ bool_t	flg_sel_data_n[MBR_DATA_EDIT_KIND_MAX_N][DATA_N_MAX_N] = {
 		FALSE,	/* DATA_N_BAR, */
 		FALSE,	/* DATA_N_NIN, */
 
-		TRUE,	/* DATA_N_CLASS, */
-
 		TRUE,	/* DATA_N_NEXT_PAGE, */
 	},
 };
@@ -895,6 +902,8 @@ long	data_page_n_tab[] = {
 	1,	/* DATA_N_RESI_ELEC, */
 	1,	/* DATA_N_RESI_POIS, */
 
+	1,	/* DATA_N_CLASS, */
+
 	1,	/* DATA_N_FIG, */
 	1,	/* DATA_N_MON, */
 	1,	/* DATA_N_HUN, */
@@ -908,8 +917,6 @@ long	data_page_n_tab[] = {
 	1,	/* DATA_N_BAR, */
 	1,	/* DATA_N_NIN, */
 
-	1,	/* DATA_N_CLASS, */
-
 	DATA_PAGE_N_ALL,	/* DATA_N_NEXT_PAGE, */
 };
 
