@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.29 2007/02/06 08:19:04 bowkenken Exp $
+* $Id: inc.h,v 1.31 2007/02/11 03:42:23 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -1711,29 +1711,35 @@
 #  include <WSCwindow.h>
 #  include "gmain.h"
 #  include "misc.h"
+#  include "chr.h"
 #  include "draw.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
+#  include "chr-prot.h"
 #  include "draw-prot.h"
 #  include "call-prot.h"
 # elif	defined( D_GTK )
 #  include "gmain.h"
 #  include "misc.h"
+#  include "chr.h"
 #  include "draw.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
 #  include "PcgDun.h"
 #  include "GlobalVar.h"
 #  include "gmain-prot.h"
+#  include "chr-prot.h"
 #  include "draw-prot.h"
 #  include "call-prot.h"
 # else
 #  include "gmain.h"
 #  include "misc.h"
+#  include "chr.h"
 #  include "draw.h"
+#  include "chr-prot.h"
 #  include "call-prot.h"
 # endif
 
