@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.180 2007/01/16 18:37:45 bowkenken Exp $
+* $Id: party.c,v 1.183 2007/02/06 17:30:27 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -213,48 +213,64 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, 0 );
+	str_nz_cpy( ls_mbr[0]->graph_name, "mon_150.gif",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
+	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.gif",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
+	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.gif",
+			FILE_NAME_MAX_LEN );
 
 	/* item */
 
@@ -412,48 +428,64 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_NINJA, 0 );
+	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.gif",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
+	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.gif",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
+	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.gif",
+			FILE_NAME_MAX_LEN );
 
 	/* ã */
 
@@ -799,6 +831,13 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
 			TRUE, FALSE, TRUE );
 
+	i = 0;
+	sub_kind.ring = RING_KIND_STRENGTH;
+	sub_kind.amulet = AMULET_KIND_NULL;
+	sub_kind.necklace = NECKLACE_KIND_NULL;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_ACCE, &sub_kind,
+			TRUE, FALSE, TRUE );
+
 	i = 0;
 	sub_kind.ring = RING_KIND_NULL;
 	sub_kind.amulet = AMULET_KIND_NULL;
@@ -1112,6 +1151,8 @@ void	new_mbr(
 
 	mbr->prev = NULL;
 	mbr->next = NULL;
+	mbr->sort_chr_next = NULL;
+
 	mbr->kind = CHR_KIND_MBR;
 	str_nz_cpy( mbr->name, name, MBR_NAME_MAX_LEN );
 	mbr->mbr_n = MBR_N_NOT_JOIN;
@@ -1252,6 +1293,8 @@ void	new_mbr(
 	mbr->work.dismissal_turn = 0;
 	mbr->work.flg_used_energy_drain = FALSE;
 
+	mbr->graph_name[0] = '\0';
+
 	set_chr_id( mbr, get_ls_mbr(), LS_MBR_MAX_N );
 
 	/**/
