@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.44 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: ver.h,v 1.47 2007/02/06 10:53:52 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -37,7 +37,7 @@
 #define	STR_VER_GAME	VERSION
 
 #define	STR_SINCE	"1993"
-#define	STR_LATEST	"2006"
+#define	STR_LATEST	"2007"
 #define	STR_AUTHOR	"YOSHIMURA Tomohiko"
 
 #define	STR_WEB	"http://lnl.sourceforge.jp/"
@@ -46,11 +46,11 @@
 #define	STR_TITLE_1	"Created by"
 #define	STR_HANDLE_1	"BowKenKen"
 
-#define	STR_TITLE_2	"Character Designer"
-#define	STR_HANDLE_2	"[RPG DOT]"
+#define	STR_TITLE_2	"Graphic Design"
+#define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP, kokusi(yujyu)"
 
 #define	STR_TITLE_THANKS	"Special Thanks"
-#define	STR_HANDLE_THANKS	"TeaMiKL and you"
+#define	STR_HANDLE_THANKS	"TeaMiKL, nnn and you"
 
 #define	STR_FMT_COPYRIGHT	\
 		"--------------------------------" \
